Rect

Struct Rect 

pub struct Rect {
    pub x: u16,
    pub y: u16,
    pub width: u16,
    pub height: u16,
}
A simple rectangle used in the computation of the layout and to give widgets an hint about the area they are supposed to render to.

Fields

x: u16y: u16width: u16height: u16

Implementations

Source

impl Rect

pub fn new(x: u16, y: u16, width: u16, height: u16) -> Rect

Creates a new rect, with width and height limited to keep the area under max u16. If clipped, aspect ratio will be preserved.

pub fn area(self) -> u16

pub fn left(self) -> u16

pub fn right(self) -> u16

pub fn top(self) -> u16

pub fn bottom(self) -> u16

pub fn inner(self, margin: &Margin) -> Rect

pub fn union(self, other: Rect) -> Rect

pub fn intersection(self, other: Rect) -> Rect

pub fn intersects(self, other: Rect) -> bool